datastructuretools.ObjectInventory
==================================

.. abjad-lineage:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory

.. autoclass:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.append
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.count
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.extend
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.insert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.pop
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.remove
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.reverse
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__add__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setslice__
   :noindex:
